#include "functionsBEM.hpp"

#include <gmsh.h>
#include <iostream>

int main(int argc, char **argv)
{
    if (argc < 2)
    {
        std::cout << "Usage: " << argv[0] << " <geo_file>\n";
        return 0;
    }

    double start = omp_get_wtime();
    int nthreads = omp_get_max_threads();
    gmsh::initialize();
    omp_set_num_threads(nthreads);

    gmsh::open(argv[1]);
    gmsh::model::mesh::generate(2);

    // will map the 1d element tag onto the corresponding electroPressure resulting from BEM code
    std::map<int, double> electrostaticPressure;
    int nbViews = 0;
    std::map<int,std::pair<double,double>> nodalDisplacements;
    const bool postProcessing = true;
    const bool meshUntangler = false;

    solverBEM(electrostaticPressure, nbViews, nodalDisplacements, postProcessing, 1, meshUntangler); // iteration number randomly set to 1

    if(postProcessing)
        gmsh::fltk::run();
    
    gmsh::finalize();
    return 0;
}
